// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------

// ====================================================================
//	reusable image processing stuff
// ====================================================================

#if defined(_WIN32) || defined(__MINGW32__) || defined(__CYGWIN__)
#include <windows.h>
#else
#include <unistd.h>
#endif

#include "common.h"
#include "config.h"

#if defined(__ATARI__) || defined(__MINGW32__)
#include "FreeImage.3.15.3.h"
#else
#include "FreeImage.3.15.4.h"
#endif

#include "imagepkg.h"
#include "pcsimage.h"

#include "quantize_som.h"

extern Arguments g_allargs;

// --------------------------------------------------------------------

#ifdef CRYPTOCHROME

#include "cchrome.hh"

#define sleep(x) Sleep(1000 * x)

//#if defined(_WIN32) && !defined(__MINGW32__)
//# include <windows.h>
//# define sleep(x) Sleep(1000 * x)
//#else
//# if defined(__MINGW32__)
//#  include <process.h>
//# else
//#  include <unistd.h>
//# endif
//#endif

//4: 48.05->49.18 = 1.13
//6: 51:00->52.30 = 1.30
//7: 54:00->55.45 = 1.45

// 7 = 1.45s : 15.00s/thread
// 6 = 1.30s : 15.00s/thread
// 4 = 1.13s : 18.25s/thread

int NUM_THREADS = 1;
int NUM_ROUNDS = 1;

class threadstate
{
public:
	
	PCSImage* img;
	cchrome* instance;
	long_t seed;
	int threadid;
	double score;
	volatile int* volatile pactive;
	volatile bool exit;
};

#if (0)
//RTYPE
cchrome::ccconfig cfg
(
	/*seed=*/19427339,
	/*saturation=*/0.8,
	/*degamma=*/1.2,
	/*accuracy_population_curve=*/0.775,
	/*differential_population_curve=*/1.0,
	/*population_cutoff=*/64,
	/*differential_luma_sig=*/0.025,
	/*differential_chroma_sig=*/0.005
);
#endif

#if (0)
//MSLUG M3
cchrome::ccconfig cfg
(
	/*seed=*/19427339,
	/*saturation=*/1.0,
	/*degamma=*/1.0,
	/*accuracy_population_curve=*/0.0,
	/*differential_population_curve=*/1.0,
	/*population_cutoff=*/0,
	/*source_cap=*/112,
	/*differential_luma_sig=*/0.025,
	/*differential_chroma_sig=*/0.005	
);
#endif

#if (0)
//MSLUG M12
cchrome::ccconfig cfg
(
	/*seed=*/19427339,
	/*saturation=*/0.9,
	/*degamma=*/1.0,
	/*accuracy_population_curve=*/0.0,
	/*differential_population_curve=*/1.0,
	/*population_cutoff=*/0,
	/*source_cap=*/384,
	/*differential_luma_sig=*/0.025,
	/*differential_chroma_sig=*/0.005	
);
#endif

#if (0)
cchrome::ccconfig cfg
(
	/*seed=*/19427339,
	/*saturation=*/0.9,
	/*degamma=*/1.0,
	/*accuracy_population_curve=*/0.775,
	/*differential_population_curve=*/1.0,
	/*population_cutoff=*/64,
	/*source_cap=*/384,
	/*differential_luma_sig=*/0.025,
	/*differential_chroma_sig=*/0.005	
);
#endif	

cchrome::ccconfig cfg
(
	/*seed=*/19427339,
	/*fields=*/2,
	/*saturation=*/0.8,
	/*ingamma=*/1.0,
	/*degamma=*/1.0,
	/*spread=*/2.0,								// mutation rate distribution
	/*accuracy_population_curve=*/0.775,		// 0 = flat population model, ...1 = err*(pop^curve)
	/*differential_population_curve=*/1.0,		// 0...1 = luma_err/chroma_err*(pop^curve)
	/*population_cutoff=*/0,
	/*source_cap=*/128,
	/*differential_luma_sig=*/	0.025,//	0.025,
	/*differential_chroma_sig=*/	0.005,//		0.005	
	/*populationcontrol=*/cchrome::ccconfig::PopulationCtrl_LINEAR,
	/*popctrlpow=*/1.0f
);
	
void* SMPThread(void* pParams)
{
	threadstate* ts = (threadstate*)pParams;
		
	cchrome::ccconfig threadcfg(cfg);
	threadcfg.seed = ts->seed;

	cchrome cc(*(ts->img), threadcfg, ts->threadid);
	cc.crunch(ts->img->get_active_source(), NUM_ROUNDS, g_allargs.ccmaxtrap, g_allargs.ccseek);
	ts->instance = &cc;

	ts->score = cc.getscore();

	// indicate thread worker complete
	volatile int& counter = *(ts->pactive);
	__sync_fetch_and_sub(&counter, (int)1);
	//counter--;

	// don't exit until	main thread is ready
	while (!ts->exit)
	{
		sleep(1);
	}

	return 0;
}

bool PCSImage::convert_cc()
{	
	if (g_allargs.verbose)
		printf("processing image...\n");

	// reduce image to capped colour count
	Quantize_SOM colourcount_quantizer(active_source_, g_allargs.ccincap);

	if (colourcount_quantizer.analyse())
	{
		colourcount_quantizer.generate_colours();
		colourcount_quantizer.remap_pixels();
	}

	//
		
	NUM_THREADS = g_allargs.ccthreads;
	NUM_ROUNDS = g_allargs.ccrounds;
	cfg.fields = g_allargs.ccfields;
	cfg.saturation = g_allargs.ccsat;
	cfg.seed = g_allargs.ccseed;
	cfg.source_cap = g_allargs.ccincap;
	cfg.ingamma = g_allargs.ccingamma;
	cfg.degamma = g_allargs.ccdegamma;
	cfg.differential_luma_sig = g_allargs.ccdls;
	cfg.differential_chroma_sig = g_allargs.ccdcs;
	cfg.accuracy_population_curve = g_allargs.ccapc;
	cfg.differential_population_curve = g_allargs.ccdpc;
	cfg.populationcontrol = cchrome::ccconfig::PopulationCtrl(g_allargs.ccpopctrl);
	cfg.popctrlpow = g_allargs.ccpopctrlpow;

	// create error buffer
	error_ = ImagePkg::instance().read_blank(display_width_, display_height_);
		
	cc_field0_ = ImagePkg::instance().read_blank(display_width_, display_height_);
	cc_field1_ = ImagePkg::instance().read_blank(display_width_, display_height_);
		
	if (NUM_THREADS > 1)
	{
		int threadId[8];
#if !defined(__MINGW32__)
		pthread_t threads[8];
		pthread_attr_t threadattr[8];	
#endif
		volatile threadstate states[8];
		
		mersenne_twister prng;
		prng.reset(cfg.seed);
		
		//SetThreadAffinityMask(GetCurrentThread(), (1 << 0));
		
		volatile int active = NUM_THREADS;
		
		for (int t = 0; t < NUM_THREADS; t++)
		{
			states[t].img = this;
			states[t].threadid = t;
			states[t].seed = prng.genU32();
			states[t].pactive = &active;
			states[t].score = 1e20;
			states[t].exit = false;
			states[t].instance = 0;

#if defined(__MINGW32__)
//			_beginthread(&SMPThread, 0, (void*)(&states[t]));

			HANDLE hThread = 
				CreateThread(
					NULL, //Choose default security
					0, //Default stack size
					(LPTHREAD_START_ROUTINE)&SMPThread,	//Routine to execute
					(LPVOID)&states[t], //Thread parameter
					0, //Immediately run the thread
					&threadId[t] //Thread Id
				);

#else
			threadId[t] = pthread_create
			(
				/*pthread_t *thread=*/&threads[t], 
				/*const pthread_attr_t *attr=*/NULL,//&threadattr[t],
	    		/*void *(*start_routine)(void*)=*/&SMPThread, 
	    		/*void *arg=*/(void*)(&states[t])
	    	);
#endif

			// allow space between printfs
			sleep(1);
	
	//		int mask = (1 << t);
	
	//		SetThreadAffinityMask(hThread, mask);
		}
		
		while (active > 0) 
		{ 
			sleep(1);
		}
		
		cchrome cc(*this, /*config=*/cfg, /*id=*/9999);
		double best_score = 1e20;
		int best_thread = -1;
		for (int t = 0; t < NUM_THREADS; t++)
		{
			if (states[t].score < best_score)
			{
				best_score = states[t].score;
				best_thread = t;
			}
		}	
		
		assert(best_thread != -1);
		
		cchrome* instace = states[best_thread].instance;
		cc.adopt(*instace);
		
		for (int t = 0; t < NUM_THREADS; t++)
		{
			states[t].exit = true;
		}	
		
		printf(">>> best of threads = %f\n", best_score);
	
		cc.convert(/*crunch=*/false, active_source_, error_, cc_field0_, cc_field1_, NUM_ROUNDS, g_allargs.ccmaxtrap, g_allargs.ccseek);
	}			
	else
	{
		cchrome cc(*this, /*config=*/cfg, /*id=*/0);
		cc.convert(/*crunch=*/true, active_source_, error_, cc_field0_, cc_field1_, NUM_ROUNDS, g_allargs.ccmaxtrap, g_allargs.ccseek);
	}
			
	
	return true;
}

#endif
	
// --------------------------------------------------------------------
