// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------

#ifndef diagnosticunit_h_
#define diagnosticunit_h_

// ====================================================================
//  diagnostic/error-measurement unit
// ====================================================================

// --------------------------------------------------------------------
// object representing an error-measurement implementation
// --------------------------------------------------------------------

enum DiagnosticSpace
{
	DiagnosticSpace_8bit,				// input space
	DiagnosticSpace_native_virtual,		// output space
	DiagnosticSpace_field				// single field space
};

class DiagnosticUnit
{
protected:
	
	signed short w_;
	signed short h_;
	signed short colourdepth_;
	signed short fields_;
	DiagnosticSpace space_;
	std::string err_name_;

	calc_real err_;
	calc_real dots_;

	ImagePkg& imgpkg_; 
		
public:
	
	virtual ~DiagnosticUnit();

	DiagnosticUnit
	(
		signed short _w, signed short _h, 
		signed short _colourdepth, 
		signed short _fields, 
		DiagnosticSpace _space, 
		const char* const _ename = "none"
	);
	
	// most reduce methods can sample all error dimensions at once, because image colour remapping and feedback are happening together
	virtual void sample
	(
		FIBITMAP* _result, signed short _x, signed short _y, 
		arg_real _fpx, arg_real _fpy, arg_real _fpz, 
		arg_real _fsx, arg_real _fsy, arg_real _fsz
	) = 0;

	// evaluate result
	virtual void evaluate(FIBITMAP* _result) = 0;
	
	virtual void reset();
	
	// quantize sample in specific space
	inline void quantize(calc_real& _x, calc_real& _y, calc_real& _z)
	{
		calc_real r = 0.0f;
		
		switch (space_)
		{
		case DiagnosticSpace_8bit:
			_x = col2f(f2col(_x));
			_y = col2f(f2col(_y));
			_z = col2f(f2col(_z));
			break;			
		case DiagnosticSpace_native_virtual:
			r = (calc_real)nvi_crange(colourdepth_, fields_);
			_x = range2f(f2range(_x, r), r);
			_y = range2f(f2range(_y, r), r);
			_z = range2f(f2range(_z, r), r);
			break;			
		case DiagnosticSpace_field:
			r = (calc_real)pal_crange(colourdepth_);
			_x = range2f(f2range(_x, r), r);
			_y = range2f(f2range(_y, r), r);
			_z = range2f(f2range(_z, r), r);
			break;			
		}
	}
};

// --------------------------------------------------------------------

#endif // diagnosticunit_h_
