// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------

#ifndef errorunit_h_
#define errorunit_h_

// ====================================================================
//  error-diffusion unit
// ====================================================================

#include "lcg.h"

// --------------------------------------------------------------------
// 3-element error component

class xyzerror
{
public:
		
	xyzerror()
		: x(0.0f), y(0.0f), z(0.0f)
	{
	}

	float x;
	float y;
	float z;
};

// --------------------------------------------------------------------
// object representing an error-diffusion implementation
// --------------------------------------------------------------------

class ErrorUnit : public LCG
{
protected:
	
	signed short field_;
	signed short fields_;
	signed short w_;
	signed short h_;
	signed short iteration_;
	signed short max_iterations_;
	float error_scale_;
	float field_magnitude_;
	signed short direction_;
	
	xyzerror* fieldbuffers_[max_fields];
	xyzerror* spatialbuffer_;
	
public:
	
	virtual ~ErrorUnit();

	ErrorUnit(signed short _w, signed short _h, signed short _colourdepth, signed short _fields, float _error_level);

	void set_field(signed short _field);
	void set_iteration(signed short _i, signed short _mi);
	void set_sweep(signed short _direction);

	// most reduce methods can sample all error dimensions at once, because image colour remapping and feedback are happening together
	virtual void sample(signed short _x, signed short _y, float& _ex, float& _ey, float& _ez) { _ex = 0.0f; _ey = 0.0f; _ez = 0.0f; }
	virtual void feedback(signed short _x, signed short _y, float _ex, float _ey, float _ez) { }
	
	// reduce method 3 generates the field palette first, then remaps the image later...
	// field error needs to be sampled while generating the palette, but spatial error needs to be sampled while remapping the image to the palette 
	// so we need to split the sampling interface for the two types

	virtual void sample_field(signed short _x, signed short _y, float& _ex, float& _ey, float& _ez) { _ex = 0.0f; _ey = 0.0f; _ez = 0.0f; }
	virtual void feedback_field(signed short _x, signed short _y, float _ex, float _ey, float _ez) { }
	
	virtual void sample_spatial(signed short _x, signed short _y, float& _ex, float& _ey, float& _ez) { _ex = 0.0f; _ey = 0.0f; _ez = 0.0f; }
	virtual void feedback_spatial(signed short _x, signed short _y, float _ex, float _ey, float _ez) { }

};

// --------------------------------------------------------------------

#endif // errorunit_h_
