// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------

// ====================================================================
// 	lightweight wrapper for static FreeImage interface
// ====================================================================
//	note: this is here mainly to sandbox FreeImage, in case I decide to pull the plug on it
// ====================================================================

#include "common.h"
#include "config.h"

#if defined(__ATARI__) || defined(__MINGW32__)
#include "FreeImage.3.15.3.h"
#else
#include "FreeImage.3.15.4.h"
#endif

#include "imagepkg.h"
#include "pcsimage.h"

extern Arguments g_allargs;

// --------------------------------------------------------------------

ImagePkg* ImagePkg::instance_ = 0;

ImagePkg::ImagePkg()
{
	// once-only, on first use
	FreeImage_Initialise(/*load_local_plugins_only=*/TRUE);
	
	// get version info
	version_ = FreeImage_GetVersion();

	if (!g_allargs.quiet)
		printf("opened FreeImage... [%s]\n", version_.c_str());
	
	crm_ = FreeImage_GetCopyrightMessage();
	
	FreeImage_SetOutputMessage(FreeImageErrorHandler_);
}

ImagePkg::~ImagePkg()
{
	FreeImage_DeInitialise();
	if (!g_allargs.quiet)
		printf("closed FreeImage...\n");
}
	
// --------------------------------------------------------------------

FIBITMAP* ImagePkg::read_jpg(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading jpg: %s\n", _name);
	FIBITMAP* fib = FreeImage_Load(FIF_JPEG, _name, JPEG_DEFAULT);
	return fib;
}

FIBITMAP* ImagePkg::read_tga(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading tga: %s\n", _name);
	FIBITMAP* fib = FreeImage_Load(FIF_TARGA, _name, TARGA_LOAD_RGB888);
	return fib;
}

FIBITMAP* ImagePkg::read_png(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading png: %s\n", _name);
	FIBITMAP* fib = FreeImage_Load(FIF_PNG, _name);
	return fib;
}

FIBITMAP* ImagePkg::read_bmp(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading bmp: %s\n", _name);
	FIBITMAP* fib = FreeImage_Load(FIF_BMP, _name);
	return fib;
}
		
// --------------------------------------------------------------------

bool ImagePkg::write_png(FIBITMAP *_fib, const char* const _name)
{
	BOOL result = FreeImage_Save(FIF_PNG, _fib, _name, PNG_DEFAULT);
	return (result == TRUE);
}

// --------------------------------------------------------------------
