// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------

#ifndef imagepkg_h_
#define imagepkg_h_

// ====================================================================
// 	lightweight wrapper for static FreeImage interface
// ====================================================================
//	note: this is here mainly to sandbox FreeImage, in case I decide to pull the plug on it
// ====================================================================

class ImagePkg
{
private:

	static ImagePkg* instance_;
	
	std::string version_;
	std::string crm_;
		
	//

	static void FreeImageErrorHandler_(FREE_IMAGE_FORMAT _fif, const char *_message) 
	{
		printf("\n*** ");
		if (_fif != FIF_UNKNOWN) 
		{
			printf("%s Format\n", FreeImage_GetFormatFromFIF(_fif));
		}
		printf(_message);
		printf(" ***\n");
	}
		
	ImagePkg();
	~ImagePkg();

public:
		
	static ImagePkg& instance()
	{
		if (!instance_)
			instance_ = new ImagePkg();

		return *instance_;
	}
	
	static void destroy()
	{
		delete instance_; 
		instance_ = 0;
	}
	
	
	void get_size(FIBITMAP *_fib, int& _w, int& _h)
	{
		_w = FreeImage_GetWidth(_fib);
		_h = FreeImage_GetHeight(_fib);
	}
	
	int get_depth(FIBITMAP *_fib)
	{
		return FreeImage_GetBPP(_fib);
	}
	
	void get_rgb(FIBITMAP *_fib, int _x, int _y, int _height, byte_t& _r, byte_t& _g, byte_t& _b)
	{
		RGBQUAD rgb;
		// freeimage coordinates are inverted :-z   0=lowest y coord
		FreeImage_GetPixelColor(_fib, (unsigned int)_x, (unsigned int)((_height - _y) - 1), &rgb);
		_r = rgb.rgbRed;
		_g = rgb.rgbGreen;
		_b = rgb.rgbBlue;
	}

	void put_rgb(FIBITMAP *_fib, int _x, int _y, int _height, byte_t _r, byte_t _g, byte_t _b)
	{
		RGBQUAD rgb;
		rgb.rgbRed = _r;
		rgb.rgbGreen = _g;
		rgb.rgbBlue = _b;
		rgb.rgbReserved = 0;
		// freeimage coordinates are inverted :-z   0=lowest y coord
		FreeImage_SetPixelColor(_fib, (unsigned int)_x, (unsigned int)((_height - _y) - 1), &rgb);
	}
		
	FIBITMAP* reformat(FIBITMAP *_fib)
	{
		return FreeImage_ConvertTo24Bits(_fib);
	}

	FIBITMAP* resize(FIBITMAP *_fib, int _w, int _h)
	{
		return FreeImage_Rescale(_fib, _w, _h, FILTER_BILINEAR);
	}
	
	void unload(FIBITMAP *_fib)
	{
		FreeImage_Unload(_fib);
	}
	
	FIBITMAP* read_blank(int _w, int _h)
	{
		return FreeImage_Allocate(_w, _h, 24);
	}
	
	FIBITMAP* read_jpg(const char* const _name);
	FIBITMAP* read_tga(const char* const _name);
	FIBITMAP* read_png(const char* const _name);
	FIBITMAP* read_bmp(const char* const _name);

	bool write_png(FIBITMAP *_fib, const char* const _name);
	
};

#endif // imagepkg_h_