// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------
//
// some notes:
//
//	This source is freeware	(except the 3rd party material of course) - you can do what you like with it - but using it
//	or adapting it without stating where it came from... is always bad form. ;-)
//
//	I've done my best to improve the convertor as much as possible without breaking compatibility with the old PCS
//	file format and viewers. This has been a bit limiting. I will however be breaking compatibility in the future to
//	get better quality images out.
//
//	The source includes some bits and pieces from the 'bit-twiddling-hacks' and 'magic algorithms' material easily found
//	on the interwebs. I need to mention those because I didn't invent them.
//
//	CIE/RGB colourspace conversion implemented from pseudocode found at http://www.easyrgb.com
//
// 	Most of the main code was written from scratch over the course of about a week, in very limited spare time,
//	so if see something you'd have done very differently, keep this in mind.
//	
//	The code is still in flux - some bits still need refactored into units/handlers and better isolated into modules
//	before branching off your own version, consider what the next update might look like!
//
//	There are some hacks/concessions to get this to build under MiNT/GCC headers - some of them more or less bad form,
//	but in most cases easy to correct with a little effort. These will likely get fixed when I run out of more interesting
//	things to do elsewhere.
//
//	FreeImage provides lots of file formats for free - but it produces a huge binary even if very little is actually
//	used by the application. I have tried to exclude plugins from FreeImage when built with -DPLUGINS_LITE, but they 
//	have done their best to make excluding 'buitin' plugins (of which there are a great many) without breaking lots of 
//	things. it works for a few formats but not others - needs more work.
//	FreeImage has been included pre-compiled as a .a because I'm not quite ready to release my build patches for it...
//	...you can of course build your own though. expect your binary to grow by 4mb without modifications :-)
//
//
//	todo:
//
//	- cie space needs retried
//	- perception map should take linearity and sensitivity of colour channels into account
//	- error diagnostics should take perception map into account
//	- xxxunits should clone host ptr instead of passing lots of fields from PCSImage
//
// ====================================================================
// 	application entrypoint & commandline handling
// ====================================================================

#include <iostream>
#include <algorithm>
#include <string>
#include <vector>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <locale.h>

// --------------------------------------------------------------------

#include "common.h"	// must come before SimpleOpt/SimpleGlob
#include "config.h"
#include "csvreader.h"

// --------------------------------------------------------------------

const char* const version_string = "PhotoChrome/CryptoChrome ST/E image tool v6.30";

extern "C" unsigned char PCT_PCS[];				// default sync table
extern "C" unsigned short DPT_PCS[];			// default dynamic point / colour mask table
extern "C" unsigned short DPT_PCS_original[];
extern "C" void expand_builtin_PCT();
extern "C" void expand_builtin_DPT();
extern "C" void expand_PCT_lace_sync(unsigned char* _pct_table, int _xsize);
extern "C" void expand_PCT_wakeup_protection(unsigned char* _pct_table, unsigned short* _dpt_table, int _xsize, int _ysize, int _colours, int _protect_pixel_zero);
extern "C" void count_PCT_colour_slots(unsigned char* _pct_table, int _xsize, int _ysize, int _colours);

unsigned short FIXED_COLS[MAX_PALETTE_SIZE];
int c_verbose = 0;

// --------------------------------------------------------------------
// portability stuff

// this stuff is needed for SimpleOpt/SimpleGlob
#if defined(_MSC_VER)
# include <windows.h>
# include <tchar.h>
#else
# define TCHAR		char
# define _T(x)		x
#endif

// --------------------------------------------------------------------
// 3rd party stuff

#include "SimpleOpt.h"
#include "SimpleGlob.h"

// --------------------------------------------------------------------

// define the ID values to indentify the option
enum
{ 
	OPT_HELP, 
	OPT_VERBOSE, 
	OPT_QUIET, 
	OPT_WAIT_KEY, 
	OPT_DIAGNOSTICS, 
	//
	OPT_CCMODE, 	
	OPT_CCFIELDS,
	OPT_CCROUNDS,
	OPT_CCTHREADS,
	OPT_CCSAT,
	OPT_CCINCAP,
	OPT_CCMAXTRAP,
	OPT_CCSEEK,
	OPT_CCSEED,
//	OPT_CCLOCKBW,
	OPT_CCINGAMMA,
	OPT_CCDEGAMMA,
	OPT_CCDLS,
	OPT_CCDCS,
	OPT_CCAPC,
	OPT_CCDPC,
	OPT_CCPOP,
	OPT_CCSORTMODE,
	OPT_COLOURLOCK,
	OPT_CCIGNORE,
	OPT_CCPROTECT,
	OPT_CCDODGE,
	//
	OPT_STORAGE, 
	OPT_FIELDS, 
	OPT_FIELDMODE, 
	OPT_WAKEPROT,
	OPT_COL_DEPTH, 
	OPT_METHOD, 
	OPT_LACE_TYPE, 
	OPT_LACE_SYNC,
	OPT_MULTILACE_ADJ,
	OPT_DITHER_TYPE, 
	OPT_DITHER_LEVEL, 
	OPT_ERROR_TYPE, 
	OPT_ERROR_LEVEL, 
	OPT_ERROR_ITERS, 
	OPT_SPATIAL_TYPE, 
	OPT_NN_DEPTH, 
	OPT_NN_BREADTH, 
	OPT_NN_RATE, 
	OPT_NN_RAD,
	OPT_PFM_GAMMA, 
	OPT_PFM_INFLUENCE, 
	OPT_PFM_SOURCE, 
	OPT_PCT_SOURCE, 
	OPT_DPT_SOURCE, 
	OPT_XSIZE, 
	OPT_YSIZE, 
	OPT_PLANES, 
	OPT_MIN_COLOUR,
	OPT_MAX_COLOUR,
	OPT_RESERVE_COLOUR,
	OPT_PALETTE_SIZE,
	OPT_PALETTE_STRIDE,
	OPT_PALETTE_PRELOAD,
	//
	OPT_OUTFILE,
	OPT_INFILE,
};

CSimpleOpt::SOption g_Options[] = 
{
	{ OPT_HELP, 		_T("-?"),     			SO_NONE		}, // "-?"
	{ OPT_HELP, 		_T("-h"),     			SO_NONE		}, // "-h"
	{ OPT_HELP, 		_T("--help"), 			SO_NONE		}, // "--help"
	//
	{ OPT_VERBOSE, 		_T("-v"),     			SO_NONE		}, // "-v"
	{ OPT_VERBOSE,		_T("--verbose"), 		SO_NONE		}, // "--verbose"
	//
	{ OPT_QUIET, 		_T("-q"),     			SO_NONE		}, // "-q"
	{ OPT_QUIET,		_T("--quiet"), 			SO_NONE		}, // "--quiet"
	//
	{ OPT_WAIT_KEY,		_T("-k"),     			SO_NONE		}, // "-k"
	{ OPT_WAIT_KEY,		_T("--wait-key"), 		SO_NONE		}, // "--wait-key"
	//
	{ OPT_DIAGNOSTICS,	_T("-dg"),     			SO_NONE		}, // "-d"
	{ OPT_DIAGNOSTICS,	_T("--diagnostics"),    SO_NONE		}, // "--diagnostics"
	//
	{ OPT_CCMODE,		_T("-ccmode"),     				SO_REQ_SEP		}, //
	{ OPT_CCFIELDS,		_T("-ccfields"),     			SO_REQ_SEP		},
	{ OPT_CCROUNDS,		_T("-ccrounds"),     			SO_REQ_SEP		},
	{ OPT_CCTHREADS,	_T("-ccthreads"),     			SO_REQ_SEP		},
	{ OPT_CCSAT,		_T("-ccsat"),     			SO_REQ_SEP		},
	{ OPT_CCINCAP,		_T("-ccincap"),     			SO_REQ_SEP		},
	{ OPT_CCMAXTRAP,	_T("-ccmaxtrap"),     			SO_REQ_SEP		},
	{ OPT_CCSEEK,		_T("-ccseek"),     			SO_REQ_SEP		},
	{ OPT_CCSEED,		_T("-ccseed"),     			SO_REQ_SEP		},		
	{ OPT_CCINGAMMA,	_T("-ccingamma"),     			SO_REQ_SEP		},	
	{ OPT_CCDEGAMMA,	_T("-ccdegamma"),     			SO_REQ_SEP		},	
	{ OPT_CCDLS,		_T("-ccdls"),     			SO_REQ_SEP		},	
	{ OPT_CCDCS,		_T("-ccdcs"),     			SO_REQ_SEP		},	
	{ OPT_CCAPC,		_T("-ccapc"),     			SO_REQ_SEP		},	
	{ OPT_CCDPC,		_T("-ccdpc"),     			SO_REQ_SEP		},	
	{ OPT_CCPOP,		_T("-ccpopctrl"),  			SO_REQ_SEP		},	
	{ OPT_COLOURLOCK,	_T("-ccl"),     			SO_REQ_SEP	}, // "-ccl <index=r4:g4:b4>"
	{ OPT_CCIGNORE,		_T("-ccignore"),   			SO_REQ_SEP	}, // "-ccignore <index=r8:g8:b8>"
	{ OPT_CCPROTECT,	_T("-ccprotect"),  			SO_REQ_SEP	}, // "-ccprotect <index>"
	{ OPT_CCDODGE,		_T("-ccdodge"),  			SO_REQ_SEP	}, // "-ccdodge <bitpattern>"
	{ OPT_CCSORTMODE,	_T("-ccsortmode"), 			SO_REQ_SEP	},
	//
	{ OPT_STORAGE,		_T("-s"),     			SO_REQ_SEP	}, // "-s <formatcode>"
	{ OPT_STORAGE,		_T("--storage"),   		SO_REQ_SEP	}, // "--storage <formatcode>"
	//
	{ OPT_FIELDS,		_T("-f"),     			SO_REQ_SEP	}, // "-f <#fields=1, 2, 3 or 4>"
	{ OPT_FIELDS,		_T("--fields"),   		SO_REQ_SEP	}, // "--fields <#fields=1, 2, 3 or 4>"
	//
	{ OPT_FIELDMODE,	_T("-fm"),     			SO_REQ_SEP	}, // "-fm <0,1,2>"
	{ OPT_FIELDMODE,	_T("--fieldmode"),   	SO_REQ_SEP	}, // "--fieldmode <0,1,2>"
	//
	{ OPT_WAKEPROT,		_T("-wp"),     			SO_NONE		}, // "-wp"
	{ OPT_WAKEPROT,		_T("--wake-prot"),   	SO_NONE		}, // "--wake-prot"
	//
	{ OPT_COL_DEPTH,	_T("-cd"),     			SO_REQ_SEP	}, // "-cd <#bits per channel>"
	{ OPT_COL_DEPTH,	_T("--colour-depth"),   SO_REQ_SEP	}, // "--colour-depth <#bits per channel>"
	//
	{ OPT_METHOD,		_T("-m"),     			SO_REQ_SEP	}, // "-m <method#>"
	{ OPT_METHOD,		_T("--method"),   		SO_REQ_SEP	}, // "--method <method#>"
	//
	{ OPT_LACE_TYPE,	_T("-lt"),     			SO_REQ_SEP	}, // "-lt <type#>"
	{ OPT_LACE_TYPE,	_T("--lace-type"),   	SO_REQ_SEP	}, // "--lace-type <type#>"
	//
	{ OPT_LACE_SYNC,	_T("-ls"),     			SO_NONE		}, // "-ls"
	{ OPT_LACE_SYNC,	_T("--lace-sync"),   	SO_NONE		}, // "--lace-sync"
	//
	{ OPT_MULTILACE_ADJ, _T("-mladj"),     		SO_REQ_SEP	}, // "-mladj <adj>"
	{ OPT_MULTILACE_ADJ, _T("--mlace-adj"),   	SO_REQ_SEP	}, // "--mlace-adj <adj>"
	//
	{ OPT_DITHER_TYPE,	_T("-dt"),     			SO_REQ_SEP	}, // "-dt <type#>"
	{ OPT_DITHER_TYPE,	_T("--dither-type"),   	SO_REQ_SEP	}, // "--dither-type <type#>"
	//
	{ OPT_DITHER_LEVEL,	_T("-dl"),     			SO_REQ_SEP	}, // "-dl <float>"
	{ OPT_DITHER_LEVEL,	_T("--dither-level"),   SO_REQ_SEP	}, // "--dither-level <float>"
	//
	{ OPT_ERROR_TYPE,	_T("-et"),     			SO_REQ_SEP	}, // "-et <type#>"
	{ OPT_ERROR_TYPE,	_T("--error-type"),   	SO_REQ_SEP	}, // "--error-type <type#>"
	//
	{ OPT_ERROR_LEVEL,	_T("-el"),     			SO_REQ_SEP	}, // "-el <0-100>"
	{ OPT_ERROR_LEVEL,	_T("--error-level"),   	SO_REQ_SEP	}, // "--error-level <0-100>"
	//
	{ OPT_ERROR_ITERS,	_T("-ei"),     			SO_REQ_SEP	}, // "-ei <#iterations>"
	{ OPT_ERROR_ITERS,	_T("--error-iters"),   	SO_REQ_SEP	}, // "--error-iters <#iterations>"
	//
	{ OPT_SPATIAL_TYPE,	_T("-spet"),     		SO_REQ_SEP	}, // "-spet <type#>"
	{ OPT_SPATIAL_TYPE,	_T("--spatialerr-type"),SO_REQ_SEP	}, // "--spatialerr-type <type#>"
	//
	{ OPT_NN_DEPTH,		_T("-nnd"),     		SO_REQ_SEP	}, // "-nnd <depth 1-16>"
	{ OPT_NN_DEPTH,		_T("--nn-depth"),		SO_REQ_SEP	}, // "--nn-depth <depth 1-16>"
	//
	{ OPT_NN_BREADTH,	_T("-nnb"),     		SO_REQ_SEP	}, // "-nnb <breadth 0.0-1.0>"
	{ OPT_NN_BREADTH,	_T("--nn-breadth"),		SO_REQ_SEP	}, // "--nn-breadth <breadth 0.0-1.0>"
	//
	{ OPT_NN_RATE,		_T("-nnr"),     		SO_REQ_SEP	}, // "-nnr <rate 0.0-1.0>"
	{ OPT_NN_RATE,		_T("--nn-rate"),		SO_REQ_SEP	}, // "--nn-rate <rate 0.0-1.0>"
	//
	{ OPT_NN_RAD,		_T("-nnrad"),     		SO_REQ_SEP	}, // "-nnrad <radius 0.0-100.0>"
	{ OPT_NN_RAD,		_T("--nn-radius"),		SO_REQ_SEP	}, // "--nn-radius <radius 0.0-100.0>"
	//
	{ OPT_PFM_GAMMA,	_T("-pfmg"),     		SO_REQ_SEP	}, // "-pfmg <float gamma>"
	{ OPT_PFM_GAMMA,	_T("--pfm-gamma"),   	SO_REQ_SEP	}, // "--pfm-gamma <float gamma>"
	//
	{ OPT_PFM_INFLUENCE,	_T("-pfmi"),     		SO_REQ_SEP	}, // "-pfmgi <float influence>"
	{ OPT_PFM_INFLUENCE,	_T("--pfm-influence"),  SO_REQ_SEP	}, // "--pfm-influence <float influence>"
	//
	{ OPT_PFM_SOURCE,	_T("-pfms"),     		SO_REQ_SEP	}, // "-pfms <maskfile.png>"
	{ OPT_PFM_SOURCE,	_T("--pfm-source"),  	SO_REQ_SEP	}, // "--pfm-source  <maskfile.png>"
	//
	{ OPT_PCT_SOURCE,	_T("-pct"),     		SO_REQ_SEP	}, // "-pct <pct.csv>"
	{ OPT_PCT_SOURCE,	_T("--pct-source"),  	SO_REQ_SEP	}, // "--pct-source  <pct.csv>"
	//
	{ OPT_DPT_SOURCE,	_T("-dpt"),     		SO_REQ_SEP	}, // "-dpt <dpt.csv>"
	{ OPT_DPT_SOURCE,	_T("--dpt-source"),  	SO_REQ_SEP	}, // "--dpt-source  <dpt.csv>"
	//
	{ OPT_XSIZE,  		_T("-x"),     			SO_REQ_SEP	}, // "-x <size>"
	{ OPT_XSIZE,  		_T("--xsize"),     		SO_REQ_SEP	}, // "--xsize <size>"
	//
	{ OPT_YSIZE,  		_T("-y"),     			SO_REQ_SEP	}, // "-y <size>"
	{ OPT_YSIZE,  		_T("--ysize"),     		SO_REQ_SEP	}, // "--ysize <size>"
	//
	//{ OPT_PLANES,  		_T("-pc"),     			SO_REQ_SEP }, // "-pc <planecount>"
	//{ OPT_PLANES,  		_T("--plane-count"),     SO_REQ_SEP }, // "--plane-count <planecount>"
	//
	//{ OPT_MIN_COLOUR,  	_T("-cmin"),     		SO_REQ_SEP }, // "-cmin <first usable colour>"
	//{ OPT_MIN_COLOUR,  	_T("--colour-min"),     SO_REQ_SEP }, // "--colour-min <first usable colour>"
	//
	//{ OPT_MAX_COLOUR,  	_T("-cmax"),     		SO_REQ_SEP }, // "-cmin <last usable colour>"
	//{ OPT_MAX_COLOUR,  	_T("--colour-max"),     SO_REQ_SEP }, // "--colour-max <last usable colour>"
	//
	//{ OPT_RESERVE_COL,  _T("-cr"),     			SO_REQ_SEP }, // "-cr <reserve colour>"
	//{ OPT_RESERVE_COL,  _T("--colour-reserve"), SO_REQ_SEP }, // "--colour-reserve <reserve colour>"
	//
	//{ OPT_PALETTE_SIZE, _T("-pe"),     			SO_REQ_SEP }, // "-ps <#colours per palette>"
	//{ OPT_PALETTE_SIZE, _T("--pal-entries"), 	SO_REQ_SEP }, // "--pal-entries <entries in 1 palette>"
	//
	//{ OPT_PAL_STRIDE, 	_T("-ps"),     			SO_REQ_SEP }, // "-ps <#colours per scanline>"
	//{ OPT_PAL_STRIDE, 	_T("--pal-stride"), 	SO_REQ_SEP }, // "--pal-stride <entries per scanline>"
	//
	//{ OPT_PAL_PRELOAD, 	_T("-pp"),     			SO_REQ_SEP }, // "-pp <#colours preloaded>"
	//{ OPT_PAL_PRELOAD, 	_T("--pal-preload"), 	SO_REQ_SEP }, // "--pal-preload <#colours preloaded>"
	//
	{ OPT_OUTFILE,  	_T("-o"),				SO_REQ_SEP	}, 	// "-o <outfile>
	//
	SO_END_OF_OPTIONS
};

// --------------------------------------------------------------------

static void usage(int level)
{
	if (level >= 1) 
	{
		std::cout << version_string << std::endl;
		std::cout << "built on " << __DATE__ << std::endl;
	}
	
	//fprintf(stderr, "usage: pcs5 [options] [-o outfile.pcs] infile.jpg/png\n");
	//printf("press any key...\n");
	
	//////////////XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX 
	std::cout << "usage:" << std::endl;
	std::cout << " pcs [opts] [-o <outfile>] [infile(s)]" << std::endl;
	std::cout << std::endl;
	std::cout << " infile = filename or glob (*.ext)" << std::endl;
	std::cout << std::endl;
	std::cout << " -?, -h, --help           > show help/usage" << std::endl;
	std::cout << " -v, --verbose            > more output" << std::endl;
	std::cout << " -q, --quiet              > less output" << std::endl;
	std::cout << " -k, --wait-key           > wait key on exit" << std::endl;
	std::cout << " -dg, --diagnostics       > emit diagnostics" << std::endl;
	std::cout << std::endl;
	std::cout << " CryptoChrome commands:" << std::endl;
	std::cout << " -ccmode                  > 0=PhotoChrome, 1-" << (CCMode__NUM_-1) << "=CryptoChrome:" << std::endl;
	std::cout << "                          > 1=degas, 2=playfield, 3=superpalette, 4=palette, 5=rawimage" << std::endl;
	std::cout << " -ccfields                > 1 = normal/undithered, or 2 = dualfield/dithered (2)" << std::endl;
	std::cout << " -ccrounds                > # competition rounds per thread: 1-64 (1)" << std::endl;
	std::cout << " -ccthreads               > # competing CPU threads: 1-32 (1)" << std::endl;
	std::cout << " -ccsat                   > saturation level: 0.0-1.0 (1.0)" << std::endl;
	std::cout << " -ccincap                 > cap/quantize input colour count: 16-65536 (1024)" << std::endl;
	std::cout << " -ccmaxtrap               > stop round after N useless iters: 1-24 (11)" << std::endl;
	std::cout << " -ccseek                  > seek rate: 0.0-1.0 (0.9995)" << std::endl;
	std::cout << " -ccseed                  > seed for PRNGs: any integer" << std::endl;
	std::cout << " -ccingamma               > input gamma curve: 1.0 = flat" << std::endl;
	std::cout << " -ccdegamma               > matching gamma curve: 1.0 = flat" << std::endl;
	std::cout << " -ccdls                   > differential luma significance: 0.0-1.0 (0.025)" << std::endl;
	std::cout << " -ccdcs                   > differential chroma significance: 0.0-1.0 (0.005)" << std::endl;
	std::cout << " -ccapc                   > accuracy population curve: 1.0 = flat (0.775)" << std::endl;
	std::cout << " -ccdpc                   > differential population curve: 1.0 = flat (1.000)" << std::endl;
	std::cout << " -ccpopctrl               > population control curve: (linear),log,flat,POW_VALUE" << std::endl;
	std::cout << " -ccl                     > rgb colour lock: 'index=r4:g4:b4'" << std::endl;
	std::cout << " -ccignore                > ignore rgb source colour: 'index=r8:g8:b8'" << std::endl;
	std::cout << " -ccprotect               > protect colour index: 0-15" << std::endl;
	std::cout << " -ccdodge                 > restrict colour generation to bitplane mask: (1111)" << std::endl;
	std::cout << " -ccsortmode              > sort palette: (up),down,off" << std::endl;
	std::cout << std::endl;
	std::cout << " PhotoChrome commands:" << std::endl;
	std::cout << " -f, --fields             > # image fields: 1-4" << std::endl;
	std::cout << " -fm, --fieldmode         > # field mode: 0,1,2" << std::endl;
	std::cout << " -m, --method             > reduction type: 0-" << (ReduceMethod__NUM_-1) << std::endl;
	std::cout << " -lt, --lace-type         > i'lace type: 0-" << (LaceType__NUM_-1) << std::endl;
	std::cout << " -ls, --lace-sync         > i'lace sync with DPT" << std::endl;
	std::cout << " -mladj, --mlace-adj      > i'lace method adj: 0-" << (MultiFieldAdj__NUM_-1) << std::endl;
	std::cout << " -dt, --dither-type       > input dither: 0-" << (DitherType__NUM_-1) << std::endl;
	std::cout << " -dl, --dither-level      > dither strength: 0.0-1.0" << std::endl;
	std::cout << " -et, --error-type        > output diffusion: 0-" << (ErrorType__NUM_-1) << std::endl;
	std::cout << " -el, --error-level       > error feedback: 0-100(%)" << std::endl;
	std::cout << " -ei, --error-iters       > # FIELD error iterations" << std::endl;
	std::cout << " -spet, --spatialerr-type > spatial error type: 0-" << (SpatialType__NUM_-1) << std::endl;
	std::cout << " -nnd, --nn-depth         > neural net depth: 1-16 (10)" << std::endl;
	std::cout << " -nnb, --nn-breadth       > neural net breadth: 0.0-1.0 (0.1)" << std::endl;
	std::cout << " -nnr, --nn-rate          > neural net converge rate: 0.0-1.0 (0.0025)" << std::endl;
	std::cout << " -nnrad, --nn-radius      > neural net radius: 0.0-100.0 (10.0)" << std::endl;
	std::cout << " -pfmg, --pfm-gamma       > PFM gamma" << std::endl;
	std::cout << " -pfmi                    > PFM influence" << std::endl;
	std::cout << " -pfms, --pfm-source      > PFM source PNG" << std::endl;
	std::cout << std::endl;
	std::cout << " -pct, --pct-source       > palette conversion table (.CSV)" << std::endl;
	std::cout << " -dpt, --dpt-source       > dynamic point table (.CSV)" << std::endl;
	std::cout << std::endl;
	std::cout << " -cd, --colour-depth      > native colour depth: st/3, ste/4" << std::endl;
	std::cout << " -x, --xsize              > image width: (320)" << std::endl;
	std::cout << " -y, --ysize              > image height: (200)" << std::endl;
	std::cout << " -s, --storage            > output format: 0-" << (StorageFmt__NUM_-1) << std::endl;
	std::cout << std::endl;
	std::cout << "press any key..." << std::endl;
				
	getchar();	
	exit(1);
}

// --------------------------------------------------------------------

std::string s_outfile;

static void GetArguments(int _argc, char **_argv, Arguments& _args)
{
    CSimpleOpt args(_argc, _argv, g_Options);

    // while there are arguments left to process
    while (args.Next()) 
    {
		if (args.LastError() == SO_SUCCESS) 
		{
			if (args.OptionId() == OPT_HELP) 
			{
				usage(1);
			}
			else if (args.OptionId() == OPT_VERBOSE) 
			{
				_args.verbose = true;
				c_verbose = 1;
			}
			else if (args.OptionId() == OPT_QUIET) 
			{
				_args.quiet = true;
			}
			else if (args.OptionId() == OPT_WAIT_KEY) 
			{
				_args.waitkey = true;
			}			
			else if (args.OptionId() == OPT_DIAGNOSTICS)
			{
				_args.diagnostics = true;
			}
			else if (args.OptionId() == OPT_CCMODE)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 0 || iarg >= CCMode__NUM_)
				{
					printf("error - invalid arg for ccmode: %s\n", s_arg.c_str());
					exit(1);
				}

				_args.ccmode = (CCMode)iarg;
			}
			else if (args.OptionId() == OPT_CCTHREADS)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 1 || iarg > 32)
				{
					printf("error - invalid arg for ccthreads: %s\n", s_arg.c_str());
					exit(1);
				}
				
				_args.ccthreads = iarg;	
			}
			else if (args.OptionId() == OPT_CCFIELDS)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 1 || iarg > 2)
				{
					printf("error - invalid arg for ccfields: %s\n", s_arg.c_str());
					exit(1);
				}
				
				_args.ccfields = iarg;	
			}
			else if (args.OptionId() == OPT_CCROUNDS)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 1 || iarg > 64)
				{
					printf("error - invalid arg for ccrounds: %s\n", s_arg.c_str());
					exit(1);
				}
				
				_args.ccrounds = iarg;	
			}
			else if (args.OptionId() == OPT_CCINCAP)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 16 || iarg > 65536)
				{
					printf("error - invalid arg for ccincap: %s\n", s_arg.c_str());
					exit(1);
				}
				
				_args.ccincap = iarg;	
			}
			else if (args.OptionId() == OPT_CCMAXTRAP)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 1 || iarg > 24)
				{
					printf("error - invalid arg for ccmaxtrap: %s\n", s_arg.c_str());
					exit(1);
				}
				
				_args.ccmaxtrap = iarg;	
			}	
			else if (args.OptionId() == OPT_CCSEED)
			{
				std::string s_arg = args.OptionArg();
				int iarg = atoi(s_arg.c_str());
				if (iarg < 0)
				{
					printf("error - invalid arg for ccseed: %s\n", s_arg.c_str());
					exit(1);
				}
				
				_args.ccseed = iarg;	
			}					
			//else if (args.OptionId() == OPT_CCLOCKBW)
			//{
			//	_args.cclockbw = true;
			//}
			else if (args.OptionId() == OPT_CCSORTMODE)
			{
				std::string s_pop = args.OptionArg();
				std::transform(s_pop.begin(), s_pop.end(), s_pop.begin(), mytolower);
					
				int mode = 0;
				if (s_pop.find("up") != std::string::npos) 
				{
					mode = 0;
					printf("palette sorting: dark->light\n");
				}
				else
				if (s_pop.find("down") != std::string::npos) 
				{
					mode = 1;
					printf("palette sorting: light->dark\n");
				}
				else
				if (s_pop.find("off") != std::string::npos) 
				{
					_args.ccsort = false;
					printf("palette sorting: off\n");
				}
				else
				{
					printf("error - invalid ccsortmode: %s\n", s_pop.c_str());
					exit(1);
				}
				
				_args.ccsortmode = mode;	
			}
			else if (args.OptionId() == OPT_CCPROTECT)
			{
				std::string s_arg = args.OptionArg();
				int v = atoi(s_arg.c_str());
				if (v < 0 || v > 15)
				{
					printf("error - invalid colour index for ccprotect: %s\n", s_arg.c_str());
					exit(1);
				}
				
				if (_args.ccsort)
					printf("ccprotect switch used - palette sorting: off\n");

				_args.ccsort = false;

				_args.ccprotected[v] = true;	
			}
			else if (args.OptionId() == OPT_CCDODGE)
			{
				std::string s_arg = args.OptionArg();
				int v = strtol(s_arg.c_str(), NULL, 2);
				if (v < 0 || v > 255)
				{
					printf("error - invalid bitplane pattern ccdodge: %s\n", s_arg.c_str());
					exit(1);
				}
				
				if (_args.ccsort)
					printf("ccdodge switch used with bitpattern [$%02x] - palette sorting: off\n", v);

				_args.ccsort = false;

				for (int c = 0; c < 256; c++)
				{
					if ((c & ~v) == 0)
						_args.ccprotected[c] = false;	
					else
						_args.ccprotected[c] = true;	
				}
			}
			else if (args.OptionId() == OPT_COLOURLOCK)
			{
				std::string s_arg = args.OptionArg();
				
				int idx = -1;
				int r, g, b;
				sscanf(s_arg.c_str(), "%d=%x:%x:%x", &idx, &r, &g, &b);

				if (idx < 0 || idx > 16)
				{
					printf("error - invalid arg for ccl (colour lock): %s\n", s_arg.c_str());
					exit(1);
				}

				printf("locking colour %d @ r(%x):g(%x):b(%x):\n", idx, r, g, b);

				_args.locked[idx] = 1;
				_args.lockedvals[idx].r = float(r) / 15.0f;
				_args.lockedvals[idx].g = float(g) / 15.0f;
				_args.lockedvals[idx].b = float(b) / 15.0f;

				// can't sort results if some colours are locked
				if (_args.ccsort)
					printf("ccl switch used - palette sorting: off\n");

				_args.ccsort = false;

			}
			else if (args.OptionId() == OPT_CCIGNORE)
			{
				std::string s_arg = args.OptionArg();
				
				int r, g, b;
				sscanf(s_arg.c_str(), "%x:%x:%x", &r, &g, &b);

				if (r < 0 || r > 255 || g < 0 || g > 255 || b < 0 || b > 255)
				{
					printf("error - invalid arg for ccignore: %s\n", s_arg.c_str());
					exit(1);
				}

				printf("ignoring colour r(%x):g(%x):b(%x):\n", r, g, b);

				_args.ccignore.r = float(r) / 255.0f;
				_args.ccignore.g = float(g) / 255.0f;
				_args.ccignore.b = float(b) / 255.0f;
			}
			else if (args.OptionId() == OPT_CCSAT)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg < 0.0f || farg > 1.0f)
				{
					printf("error - invalid arg for ccsat: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccsat = farg;	
			}
			else if (args.OptionId() == OPT_CCSEEK)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg < 0.0f || farg > 1.0f)
				{
					printf("error - invalid arg for ccseek: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccseek = farg;	
			}
			else if (args.OptionId() == OPT_CCINGAMMA)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg <= 0.0f || farg > 10.0f)
				{
					printf("error - invalid arg for ccingamma: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccingamma = farg;	
			}
			else if (args.OptionId() == OPT_CCDEGAMMA)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg <= 0.0f || farg > 10.0f)
				{
					printf("error - invalid arg for ccdegamma: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccdegamma = farg;	
			}
			else if (args.OptionId() == OPT_CCDLS)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg <= 0.0f || farg > 1.0f)
				{
					printf("error - invalid arg for ccdls: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccdls = farg;	
			}
			else if (args.OptionId() == OPT_CCDCS)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg <= 0.0f || farg > 1.0f)
				{
					printf("error - invalid arg for ccdcs: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccdcs = farg;	
			}
			else if (args.OptionId() == OPT_CCAPC)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg <= 0.0f || farg > 1.0f)
				{
					printf("error - invalid arg for ccapc: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccapc = farg;	
			}
			else if (args.OptionId() == OPT_CCDPC)
			{
				std::string s_arg = args.OptionArg();
				float farg = atof(s_arg.c_str());
				if (farg <= 0.0f || farg > 1.0f)
				{
					printf("error - invalid arg for ccdpc: %s\n", s_arg.c_str());
					exit(1);
				}
				_args.ccdpc = farg;	
			}
			else if (args.OptionId() == OPT_CCPOP)
			{
//				_args.ccfpc = true;	

				std::string s_pop = args.OptionArg();
				std::transform(s_pop.begin(), s_pop.end(), s_pop.begin(), mytolower);
					
				int pop = 0;
				if (s_pop.find("linear") != std::string::npos) 
				{
					pop = 0; // PopulationCtrl_LINEAR
					printf("using LINEAR population control\n");
				}
				else
				if (s_pop.find("log") != std::string::npos) 
				{
					pop = 2; // PopulationCtrl_LOG
					printf("using LOG2(x) population control\n");
				}
				else
				if (s_pop.find("flat") != std::string::npos) 
				{
					pop = 3; // PopulationCtrl_FLAT
					printf("using FLAT population control\n");
				}
				else
				{
					pop = 1; // PopulationCtrl_POW

					float poppow = atof(s_pop.c_str());
					if (poppow < 1e-4f || poppow > 2.0f)
					{
						printf("error - invalid population control power: %s\n", s_pop.c_str());
						exit(1);
					}
					printf("using POW(x,%.4f) population control\n", poppow);

					_args.ccpopctrlpow = poppow;
				}
				
				_args.ccpopctrl = pop;	
			}
			else if (args.OptionId() == OPT_XSIZE)
			{
				std::string s_xsize = args.OptionArg();
				int xsize = atoi(s_xsize.c_str());
				if (xsize < 2 || xsize > 32768)
				{
					printf("error - invalid x size: %s\n", s_xsize.c_str());
					exit(1);
				}
				
				_args.xsize = xsize;	
			}
			else if (args.OptionId() == OPT_YSIZE)
			{
				std::string s_ysize = args.OptionArg();
				int ysize = atoi(s_ysize.c_str());
				if (ysize < 2 || ysize > 32768)
				{
					printf("error - invalid y size: %s\n", s_ysize.c_str());
					exit(1);
				}
				
				_args.ysize = ysize;	
			}
			else if (args.OptionId() == OPT_FIELDS)
			{
				std::string s_f = args.OptionArg();
				int f = atoi(s_f.c_str());
				if (f < 0 || f > 4)
				{
					printf("error - invalid field count: %s\n", s_f.c_str());
					exit(1);
				}
				
				_args.fields = f;	
			}			
			else if (args.OptionId() == OPT_FIELDMODE)
			{
				std::string s_f = args.OptionArg();
				int f = atoi(s_f.c_str());
				if (f < 0 || f >= FieldMode__NUM_)
				{
					printf("error - invalid field mode: %s\n", s_f.c_str());
					exit(1);
				}
								
				_args.fieldmode = FieldMode(f);	
			}			
			else if (args.OptionId() == OPT_WAKEPROT) 
			{
				_args.wake_protect = true;
			}			
			else if (args.OptionId() == OPT_COL_DEPTH)
			{
				int depth = ColourDepth_DEFAULT;
				
				std::string s_m = args.OptionArg();
				std::transform(s_m.begin(), s_m.end(), s_m.begin(), mytolower);
					
				if ((s_m.find("ste") != std::string::npos) ||
					(s_m.compare("4096") == 0) ||
					(s_m.compare("12bit") == 0))
				{
					depth = ColourDepth_STE;	
				}
				else
				if ((s_m.compare("stfm") == 0) ||
					(s_m.compare("stf") == 0) ||
					(s_m.compare("st") == 0) ||
					(s_m.compare("512") == 0) ||
					(s_m.compare("9bit") == 0))
				{
					depth = ColourDepth_ST;	
				}
				else
				{						
					depth = atoi(s_m.c_str());
					if (depth < 3 || depth > 6)
					{
						printf("error - invalid native colour depth: %s\n", s_m.c_str());
						exit(1);
					}
				}
				_args.colourdepth = depth;	
			}
			else if (args.OptionId() == OPT_STORAGE)
			{
				std::string s_s = args.OptionArg();
				int s = atoi(s_s.c_str());
				if (s < 0 || s >= StorageFmt__NUM_)
				{
					printf("error - invalid storage format: %s\n", s_s.c_str());
					exit(1);
				}
				_args.storage = StorageFmt(s);	
			}
			else if (args.OptionId() == OPT_METHOD)
			{
				std::string s_m = args.OptionArg();
				int m = atoi(s_m.c_str());
				if (m < 0 || m >= ReduceMethod__NUM_)
				{
					printf("error - invalid method: %s\n", s_m.c_str());
					exit(1);
				}
				_args.method = ReduceMethod(m);	
			}
			else if (args.OptionId() == OPT_LACE_TYPE)
			{
				std::string s_m = args.OptionArg();
				int m = atoi(s_m.c_str());
				if (m < 0 || m >= LaceType__NUM_)
				{
					printf("error - invalid interlace type: %s\n", s_m.c_str());
					exit(1);
				}
				_args.lacetype = LaceType(m);	
			}
			else if (args.OptionId() == OPT_LACE_SYNC) 
			{
				_args.lacesync = true;
			}			
			else if (args.OptionId() == OPT_MULTILACE_ADJ)
			{
				std::string s_m = args.OptionArg();
				int m = atoi(s_m.c_str());
				if (m < 0 || m >= MultiFieldAdj__NUM_)
				{
					printf("error - invalid multifield lace method adjust: %s\n", s_m.c_str());
					exit(1);
				}
				_args.multifieldadj = MultiFieldAdj(m);	
			}
			else if (args.OptionId() == OPT_DITHER_TYPE)
			{
				std::string s_m = args.OptionArg();
				int m = atoi(s_m.c_str());
				if (m < 0 || m >= DitherType__NUM_)
				{
					printf("error - invalid dither type: %s\n", s_m.c_str());
					exit(1);
				}
				_args.dithertype = DitherType(m);
			}	
			else if (args.OptionId() == OPT_DITHER_LEVEL)
			{
				std::string s_m = args.OptionArg();
				float m = atof(s_m.c_str());
				if (m < -8.0f || m > 8.0f)
				{
					printf("error - invalid dither level: %s\n", s_m.c_str());
					exit(1);
				}
				_args.ditherlevel = m;	
			}
			else if (args.OptionId() == OPT_ERROR_TYPE)
			{
				std::string s_e = args.OptionArg();
				int e = atoi(s_e.c_str());
				if (e < 0 || e >= ErrorType__NUM_)
				{
					printf("error - invalid error diffusion type: %s\n", s_e.c_str());
					exit(1);
				}
				_args.errortype = ErrorType(e);	
			}		
			else if (args.OptionId() == OPT_ERROR_LEVEL)
			{
				std::string s_el = args.OptionArg();
				float el = atof(s_el.c_str());
				if (el < 0.0f || el > 100.0f)
				{
					printf("error - invalid error level: %s%%\n", s_el.c_str());
					exit(1);
				}
				_args.errorlevel = xclamp<float>
				(
					(el / 100.0f), 0.0f, 1.0f
				);	
			}
			else if (args.OptionId() == OPT_ERROR_ITERS)
			{
				std::string s_i = args.OptionArg();
				int i = atoi(s_i.c_str());
				if (i < 1 || i >= 50)
				{
					printf("error - invalid error number of error iterations: %s\n", s_i.c_str());
					exit(1);
				}
				_args.erroriters = i;	
			}								
			else if (args.OptionId() == OPT_SPATIAL_TYPE)
			{
				std::string s_e = args.OptionArg();
				int e = atoi(s_e.c_str());
				if (e < 0 || e >= SpatialType__NUM_)
				{
					printf("error - invalid error diffusion type: %s\n", s_e.c_str());
					exit(1);
				}
				_args.spatialtype = SpatialType(e);	
			}		
			else if (args.OptionId() == OPT_PFM_GAMMA)
			{
				std::string s_m = args.OptionArg();
				float m = atof(s_m.c_str());
				if (m < 0.0 || m > 100.0)
				{
					printf("error - invalid PFM gamma: %s\n", s_m.c_str());
					exit(1);
				}
				_args.pfm_gamma = m;	
			}
			else if (args.OptionId() == OPT_PFM_INFLUENCE)
			{
				std::string s_m = args.OptionArg();
				float m = atof(s_m.c_str());
				if (m < 0.0 || m > 1.0)
				{
					printf("error - invalid PFM influence: %s (range 0.0 -> 1.0)\n", s_m.c_str());
					exit(1);
				}
				_args.pfm_influence = m;	
			}
			else if (args.OptionId() == OPT_NN_DEPTH)
			{
				std::string s_e = args.OptionArg();
				int e = atoi(s_e.c_str());
				if (e < 1 || e > 20)
				{
					printf("error - invalid NN depth: %s\n", s_e.c_str());
					exit(1);
				}
				_args.nn_depth = SpatialType(e);	
			}					
			else if (args.OptionId() == OPT_NN_BREADTH)
			{
				std::string s_m = args.OptionArg();
				float m = atof(s_m.c_str());
				if (m < 0.01 || m > 1.0)
				{
					printf("error - invalid NN breadth: %s (range 0.0 -> 1.0)\n", s_m.c_str());
					exit(1);
				}
				_args.nn_breadth = m;	
			}
			else if (args.OptionId() == OPT_NN_RATE)
			{
				std::string s_m = args.OptionArg();
				float m = atof(s_m.c_str());
				if (m == 0.0 || m > 1.0)
				{
					printf("error - invalid NN rate: %s (range [epsilon] -> 1.0)\n", s_m.c_str());
					exit(1);
				}
				_args.nn_rate = m;	
			}
			else if (args.OptionId() == OPT_NN_RAD)
			{
				std::string s_m = args.OptionArg();
				float m = atof(s_m.c_str());
				if (m == 0.0 || m > 100.0)
				{
					printf("error - invalid NN radius: %s (range [epsilon] -> 100.0)\n", s_m.c_str());
					exit(1);
				}
				_args.nn_radius = m;	
			}
			else if (args.OptionId() == OPT_PFM_SOURCE)
			{
				_args.pfm_source = args.OptionArg();
			}
			else if (args.OptionId() == OPT_PCT_SOURCE)
			{
				_args.pct_source = args.OptionArg();
			}										
			else if (args.OptionId() == OPT_DPT_SOURCE)
			{
				_args.dpt_source = args.OptionArg();
			}										
			else if (args.OptionId() == OPT_OUTFILE)
			{
				s_outfile = args.OptionArg();
			}
		}
		else 
		{
			printf("error - invalid argument: %s\n", args.OptionText());
			exit(1);
		}
    }

	if (!_args.quiet)
	{
		std::cout << "/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\" << std::endl;
		printf("%s\n", version_string);
	}

	// expand input filenames    
    CSimpleGlob glob(SG_GLOB_NODOT|SG_GLOB_NOCHECK);
    if (SG_SUCCESS != glob.Add(args.FileCount(), args.Files())) 
    {
        printf("error globbing files\n");
			exit(1);
    }
 
 	// check infile/outfile specification rules  
    if (glob.FileCount() == 0)
    {
		fprintf(stderr, "error - no input files specified!\n");
		printf("press any key...\n");
		getchar();	
		exit(1);
    }
	else if ((glob.FileCount() > 1) && !s_outfile.empty())
    {
		fprintf(stderr, "error - multiple inputs can't be converted to a single file! remove [-o <outfile>] from spec for batching\n");
		printf("press any key...\n");
		getchar();	
		exit(1);
    }
    else
    {
    	// collect input files
		for (int n = 0; n < glob.FileCount(); ++n) 
		{
		    std::string namein(glob.File(n));
		    std::string nameout(namein);
		    
		    // transform file extension to PCS
		    
			size_t p = nameout.find_last_of(".");
			if (p != std::string::npos)
				nameout = nameout.substr(0, p);
			nameout.append(".PCS");			
			
		    _args.tasks.push_back(task(namein.c_str(), nameout.c_str()));
		}
		
		// if only one input file, specifying the outfile directly is ok
		if (!s_outfile.empty())
		{
			_args.tasks[0].outfile_ = s_outfile;
		}
 	}			

	// read user PCT file, if any 
/*
	// convert old DPT mask values into new format
	int i = 0;	
	for (int y = 0; y < 40; ++y)
	{
		for (int x = 0; x < 8; ++x)
		{
			unsigned short v = DPT_PCS_original[i] >> 8;
	
			if (v == 16)
				printf("%04x, ", 0);
			else
				printf("%04x, ", (int)(1 << v));
				
			++i;
		}
		printf("\n");
	}
*/	
	if (_args.pct_source.empty())
	{
		if ((_args.xsize == 320) && (_args.ccmode == CCMode_NONE))
		{
			expand_builtin_PCT();
			// use builtin table for PCS
			_args.aPCT = PCT_PCS;
		}	
		else
		{
			// xsize has been specified but without a display profile - most likely to 
			// conveniently leverage the image handling parts of the tool without generating 
			// any display-specific output...

			if (_args.ccmode == CCMode_NONE)
				std::cout << "warning - specified xsize independently of PCT - image processing will continue but multipalette reduction steps will be skipped..." << std::endl;

			_args.aPCT = 0;
			_args.uPCT = 0;

			//_args.uPCT = new byte_t[_args.xsize*16];
			//memset(_args.uPCT, 0, _args.xsize*16);
			//_args.aPCT = _args.uPCT;
		}	
	}
	else
	{
		_args.uPCT = new byte_t[(_args.ysize+1) * _args.xsize * MAX_PALETTE_SIZE];
		memset(_args.uPCT, 0, (_args.ysize+1) * _args.xsize * MAX_PALETTE_SIZE);
		_args.aPCT = _args.uPCT;
		
		std::ifstream pct(_args.pct_source.c_str());
		if (!(pct.is_open() && pct.good()))
		{
			fprintf(stderr, "error - unable to locate or read specified PCT CSV file!\n");
			printf("press any key...\n");
			getchar();	
			exit(1);	
		}

		if (!_args.quiet)
		{
			std::cout << "/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\" << std::endl;
			std::cout << "reading user-defined PCT (pixel conversion / timing table)..." << std::endl;
		}


		enum parsemode_t
		{
			parsemode_scan,
			parsemode_header,
			parsemode_fixed,
			parsemode_typeid,
			parsemode_linedefs
		};
		
		int parsemode = parsemode_scan;

		int last_linedef = 1;		
		int linedef_dupes = 0;
		int linedef_pixels = 0;					
//		int valid_linedefs = 0;					
//		bool firstrow = true;
//		int valid_check = _args.xsize;
		for (CSVIterator loop(pct); loop != CSVIterator(); ++loop)
		{
			const CSVRow& r = (*loop);
			size_t s = r.size();
			if (s > 0)
			{
				// determine what kind of row
				
				if (parsemode_scan == parsemode)
				{
					std::string inspect = r[0];
					if (inspect[0] == ';')
					{
						// skip comment
						printf("skipping comment: %s\n", inspect.c_str());
					}
					else if (inspect[0] == '[')
					{
						printf("change mode: %s\n", inspect.c_str());						
						// change parse mode
						if (0 == inspect.find("[header]"))
						{
							printf("mode: [header]\n");
							parsemode = parsemode_header;
						}
						else if (0 == inspect.find("[fixed]"))
						{
							printf("mode: [fixed]\n");
							parsemode = parsemode_fixed;
						}
						else if (0 == inspect.find("[typeid]"))
						{
							printf("mode: [typeid]\n");
							parsemode = parsemode_typeid;
						}
						else 
						{
							printf("mode: [linedefs]\n");
							parsemode = parsemode_linedefs;
							last_linedef += linedef_dupes;
							linedef_dupes = atoi(&inspect[1]);
							linedef_pixels = 0;
							printf("parsing new linedef into %d lines [%d->%d]\n", 
								linedef_dupes, last_linedef, last_linedef+linedef_dupes-1);
						}
					}
					else
					{
						// unknown
						if (inspect.length() > 0)
						{
							// report any unexpected mode fields except whitespace
							if (inspect[0] != ' ' && inspect[0] != '\n' && inspect[0] != '\r' && inspect[0] != '\t')
								printf("unexpected mode: %s\n", inspect.c_str());
						}
					}
				}
				else if (parsemode_header == parsemode)
				{
/*					if (validrows >= valid_check)
					{
						fprintf(stderr, "error - invalid number of rows in PCT file!\n");
						printf("press any key...\n");
						getchar();	
						exit(1);				
					}
*/					
//					if (firstrow && (s == 5))

					std::string inspect = r[0];
					if (inspect[0] == ';')
					{
						// skip comment
						printf("skipping comment: %s\n", inspect.c_str());
					}
					else
					{
						// read profile data
						// <width>, <ncolours>, <nplanes>, <npalettes>, <nskips>, <firstline> 
						int column_value = 0;
						int column_index = 0;

						std::cout << "reading custom profile: ";

						// <width>		
						std::string colval = r[column_index++];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						column_value = atoi(colval.c_str());
						if (column_value >= 16 && column_value <= 2048)
						{	
							_args.xsize = column_value;
							
							// reallocate
							delete[] _args.uPCT;
							_args.uPCT = new byte_t[(_args.ysize+1) * _args.xsize * MAX_PALETTE_SIZE];
							_args.aPCT = _args.uPCT;
							
							//valid_check = _args.xsize;
							std::cout << "width=" << column_value << ", ";
						}
						else
						{
							fprintf(stderr, "error - invalid <width> field (%d) in profile row of PCT CSV file!\n", column_value);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}
						
						// <ncolours>		
						colval = r[column_index++];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						column_value = atoi(colval.c_str());
						if (column_value >= 3 && column_value <= 256)
						{	
							_args.colours = column_value;
							std::cout << "ncolours=" << column_value << ", ";
						}
						else
						{
							fprintf(stderr, "error - invalid <ncolours> field (%d) in profile row of PCT CSV file!\n", column_value);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}							
						
						// <nplanes>		
						colval = r[column_index++];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						column_value = atoi(colval.c_str());
						if (column_value >= 2 && column_value <= 8)
						{	
							_args.planes = column_value;
							std::cout << "nplanes=" << column_value << ", ";
						}
						else
						{
							fprintf(stderr, "error - invalid <nplanes> field (%d) in profile row of PCT CSV file!\n", column_value);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}	

						if (_args.colours > (1 << _args.planes))
						{
							fprintf(stderr, "error - invalid combination of <ncolours>,<nplanes>: ncolours > (2^nplanes)!\n");
							printf("press any key...\n");
							getchar();	
							exit(1);	
						}

						// <npalettes>		
						colval = r[column_index++];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						column_value = atoi(colval.c_str());
						if (column_value >= 1 && column_value <= 32)
						{	
							_args.palettes = column_value;
							std::cout << "npalettes=" << column_value << ", ";
						}
						else
						{
							fprintf(stderr, "error - invalid <npalettes> field (%d) in profile row of PCT CSV file!\n", column_value);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}
						
						// <nskips>		
						colval = r[column_index++];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						column_value = atoi(colval.c_str());
						if (column_value >= 0 && column_value < (_args.ysize * _args.palettes))
						{	
							_args.palette_skip = column_value;
							std::cout << "nskips=" << column_value << ", ";
						}
						else
						{
							fprintf(stderr, "error - invalid <nskips> field (%d) in profile row of PCT CSV file!\n", column_value);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}
						
						// <firstline>		
						colval = r[column_index++];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						column_value = atoi(colval.c_str());
						if (column_value >= 0 && column_value < 16384)
						{	
							_args.firstline = column_value;
							std::cout << "firstline=" << column_value << std::endl;
						}
						else
						{
							fprintf(stderr, "error - invalid <firstline> field (%d) in profile row of PCT CSV file!\n", column_value);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}																									

						parsemode = parsemode_scan;
					}
				}
				else if (parsemode_fixed == parsemode)
				{
					for (size_t c = 0; c < _args.colours; ++c)
					{
						std::string colval = r[c];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						int column_value = -1;
						sscanf(colval.c_str(), "%x", &column_value);
						FIXED_COLS[c] = column_value;
						printf(" scanned fixed: %03x\n", column_value);
					}
					
					parsemode = parsemode_scan;
				}
				else if (parsemode_typeid == parsemode)
				{
					std::string colval = r[0];
					std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
					int column_value = 0;
					sscanf(colval.c_str(), "%d", &column_value);
					printf(" scanned typeid: %d\n", column_value);
					if (column_value < 0)
						column_value = 0;
					if (column_value > 7)
						column_value = 7;
					_args.typeident = column_value;
					
					parsemode = parsemode_scan;
				}
				else if (parsemode_linedefs == parsemode)
				{
					// read timing data
					
					if (r.size() >= 2)	
					{
					
					for (size_t c = 0; c < _args.colours; ++c)
					{
						std::string colval = r[c];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						int column_value = atoi(colval.c_str());
						
						if (column_value >= _args.palettes)
						{
							fprintf(stderr, "error - invalid palette index (%d) in PCT table >= palettes per line (%d)!\n", column_value, _args.palettes);
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}							
						
						for (int linedef_row = last_linedef; linedef_row < (last_linedef + linedef_dupes); ++linedef_row)
						{			
							_args.uPCT[(((_args.xsize * linedef_row) + linedef_pixels) * MAX_PALETTE_SIZE) + c] = (unsigned char)(unsigned int)column_value;
						}
						
//						valid_linedefs += linedefs;

#ifdef _DEBUG
						if (_args.verbose)
						{
							if (column_value >= 0)
								std::cout << " ";	
							std::cout << column_value;
							if (c != s-1)
								std::cout << ", ";
						}
#endif						
					}
#ifdef _DEBUG
					if (_args.verbose)
						std::cout << std::endl;
#endif
					linedef_pixels++;
					
					// return to scanning mode on last pixel
					if (linedef_pixels == _args.xsize)
						parsemode = parsemode_scan;
					
					}
				}
				else
				{
					// syntax error in PCT
					fprintf(stderr, "error - invalid PCT file!\n");
					printf("press any key...\n");
					getchar();	
					exit(1);
				}
			}
		} 

		if (_args.verbose)	
			std::cout << (last_linedef + linedef_dupes) - 1 << " linedefs created from PCT" << std::endl;
//			std::cout << validrows << " rows read from CSV" << std::endl;

		if (_args.storage != StorageFmt_DIRECT_DISPLAY &&
			_args.storage != StorageFmt_RAW_DISPLAY && 
			_args.storage != StorageFmt_RAW_ILEAVED_DISPLAY)
		{
			if (!_args.quiet)
				std::cout << "custom profile: auto-selecting RAW_DISPLAY storage format" << std::endl;

			_args.storage = StorageFmt_RAW_DISPLAY;
		}

		if (!_args.quiet)
		{
			std::cout << "/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\/\\" << std::endl;
		}
	}

	if (_args.ccmode == CCMode_NONE)
	{
		expand_PCT_lace_sync(_args.aPCT, _args.xsize);
		count_PCT_colour_slots(_args.aPCT, _args.xsize, _args.ysize, _args.colours);
	}
	else
	{
		if (_args.ccfields == 1)
		{
			// for single-field palette reduction, turn off differential costs
			_args.ccdls = 0;
			_args.ccdcs = 0;
			_args.ccapc = 1.0;
			_args.ccdpc = 1.0;
		}
	}

	// read user DPT file, if any 

/*	
	if (_args.dpt_source.empty())
	{
		if (_args.aPCT == PCT_PCS)
		{
			expand_builtin_DPT();
			// default is to use builtin DPT table for PCS
			_args.aDPT = DPT_PCS;
		}
		else
		{
			// otherwise, don't use any DPT table!
			std::cout << "warning - no DPT specified - if image displays vertical bands you may need to mask colours under changing pixels" << std::endl;
		}
	}
*/
	if (_args.dpt_source.empty())
	{
		if (_args.ccmode != CCMode_NONE)
		{
			// do nothing
		}
		else
		if (_args.aPCT == PCT_PCS)
		{
			// default is to use builtin 320x DPT table for PCS
			expand_builtin_DPT();
			
			_args.aDPT = DPT_PCS;
		}
		else
		{
			// initialize blank DPT table
			_args.uDPT = new word_t[(_args.ysize+1) * _args.xsize];
			memset(_args.uDPT, 0, (_args.ysize+1) * _args.xsize * sizeof(word_t));
			_args.aDPT = _args.uDPT;	

			// generate DPT from wakeup timings			
			if (_args.wake_protect)
				expand_PCT_wakeup_protection(_args.uPCT, _args.uDPT, _args.xsize, _args.ysize, _args.colours, /*protect_pixel_zero=*/-1);	
		}
	}
	else
	{
		// read DPT directly from definition
		
		_args.uDPT = new word_t[_args.xsize * _args.ysize];
		_args.aDPT = _args.uDPT;
		
		std::ifstream dpt(_args.dpt_source.c_str());
		if (!(dpt.is_open() && dpt.good()))
		{
			fprintf(stderr, "error - unable to locate or read specified DPT CSV file!\n");
			printf("press any key...\n");
			getchar();	
			exit(1);	
		}

		if (!_args.quiet)
			std::cout << "reading user-defined DPT (dynamic point table / colour masks)..." << std::endl;

		int validrows = 0;					
		int validentries = 0;					
		for (CSVIterator loop(dpt); loop != CSVIterator(); ++loop)
		{
			const CSVRow& r = (*loop);
			size_t s = r.size();
			if (s > 0)
			{
				if (s >= 1 && s <= 768)
				{
					for (size_t c = 0; c < s; ++c)
					{
						if (validentries >= _args.xsize)
						{
							fprintf(stderr, "error - invalid number of entries in DPT file!\n");
							printf("press any key...\n");
							getchar();	
							exit(1);				
						}
						
						std::string colval = r[c];
						std::transform(colval.begin(), colval.end(), colval.begin(), sanitise_csv_arg);
						int column_value = -1;
						sscanf(colval.c_str(), "%x", &column_value);
																		
						_args.uDPT[validentries++] = (unsigned short)(unsigned int)column_value;

#ifdef _DEBUG
						if (_args.verbose)
						{
							//std::cout << "[" << colval.c_str() << " : " << column_value << "]";
							
							fprintf(stdout, "%04x", column_value);
							if (c != s-1)
								std::cout << ", ";
						}
#endif
					}
#ifdef _DEBUG
					if (_args.verbose)
						std::cout << std::endl;
#endif							
					validrows++;
				}
				else
				{
					// syntax error in DPT
					fprintf(stderr, "error - invalid number of columns in DPT file!\n");
					printf("press any key...\n");
					getchar();	
					exit(1);
				}
			}
		} 
		
		if (validentries != _args.xsize)
		{
			// syntax error in DPT
			fprintf(stderr, "error - too few entries (%d) in DPT file! should correspond to display width (%d).\n", validentries, _args.xsize);
			printf("press any key...\n");
			getchar();	
			exit(1);
		}
		else
		{			
			if (_args.verbose)	
				std::cout << validentries << " entries read from CSV" << std::endl;
		}
	}
	 	
 	// override interlace control in single-field mode
 	if (_args.fields == 1)
 		_args.lacetype = LaceType_OFF;

	if ((_args.fieldmode == FieldMode_SharedPalette) && (_args.fields == 1))
	{
		fprintf(stderr, "error - 'shared palette' field mode requires fields >= 2 for colour reduction\n");
		printf("press any key...\n");
		getchar();	
		exit(1);
	}

	if ((_args.fieldmode == FieldMode_SharedBitmap) && (_args.fields > 1))
	{
		fprintf(stderr, "error - 'shared bitmap' field mode requires fields==1 for colour reduction\n");
		printf("press any key...\n");
		getchar();	
		exit(1);
	}
	
	if (_args.fieldmode == FieldMode_SharedBitmap)
	{
		// sharing bitmap implies increased palette colour depth in order to generate 2 palette fields from one reduction
		// note: this requires special care on STE for intermediate storage of RGB in 12bit palette form, as 15bit colour will be generated during reduction...
		_args.colourdepth++;

		if (_args.verbose)	
			std::cout << "extending bitdepth for shared bitmap / dual palette image" << std::endl;
	}

	// don't accept more than one error iteration unless we're in a field-error propagation mode 		
 	if (
 		((_args.errortype != ErrorType_FIELD) /*&& 
 		 (_args.errortype != ErrorType_MULTIMODE)*/) /*|| 
 		(_args.fields < 2)*/
 	)
	{
 		_args.erroriters = 1;
	}
 	
}

bool process_file(const char* const _name, const char* _outfile);
bool ccgen_append_source(const char* const _name);
bool ccgen_process_multiple_sources(const char* const _outfile);
	
Arguments g_allargs;

int main(int argc, char **argv)
{
	GetArguments(argc, argv, g_allargs);

	if (g_allargs.verbose)
	{
		switch (g_allargs.colourdepth)
		{
		case ColourDepth_ST:
			printf("colour depth: ST palette (9bit)\n");
			break;
		case ColourDepth_STE:
			printf("colour depth: STE palette (12bit)\n");
			break;
		case ColourDepth_STE_X:
			printf("colour depth: STE dual palette (15bit)\n");
			break;
		case ColourDepth_FALCON:
			printf("colour depth: Falcon030 (18bit) - not yet properly supported!\n");
			exit(1);			
			break;
		default:
			printf("no obvious use case for %d-bit colour - are you sure?\n", g_allargs.colourdepth * 3);
			break;
		}
	} 
	   	
	if (g_allargs.verbose)
		for (int t = 0; t < g_allargs.tasks.size(); ++t)
			printf("task: [%s->%s]\n", 
				g_allargs.tasks[t].infile_.c_str(), 
				g_allargs.tasks[t].outfile_.c_str()
			);


	bool success = false;

	if (!g_allargs.tasks.empty())
	{
		success = true;
		
		if (g_allargs.ccmode == CCMode_SUPERPALETTE)
		{
			// cryptochrome pair reduction mapping path for texture sets
			
			for (int t = 0; t < g_allargs.tasks.size(); ++t)
			{
				success &= ccgen_append_source(g_allargs.tasks[t].infile_.c_str());
			}
			
			if (success)
				success &= ccgen_process_multiple_sources(s_outfile.c_str());
		}
		else // all other CCModes and normal PCS mode
		{	
			// normal, single-file path	
			for (int t = 0; t < g_allargs.tasks.size(); ++t)
			{
				success &= process_file(g_allargs.tasks[t].infile_.c_str(), g_allargs.tasks[t].outfile_.c_str());
			}
		}
	}
	
	if (success)
	{
		if (!g_allargs.quiet)		
			printf("complete!\n"); 
			
		if (g_allargs.waitkey) 
			getchar();
	}
	else
	{
		printf("error - press any key...\n"); getchar();
	}

	return 0;
}
