// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v6.xx - Atari ST interlaced image reduction framework
//	1991-2016 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//		evil@DHS, RA/PDX, Troed/SYNC for help testing and input on improvements
// ---------------------------------------------------------------------------------------------------------------------

#ifndef quantize_som_h_
#define quantize_som_h_

// ====================================================================
//  general purpose colour quantizer
// ====================================================================

// --------------------------------------------------------------------
// object representing an error-diffusion implementation
// --------------------------------------------------------------------

class Quantize_SOM
{
private:
	
	// --------------------------------------------------------------------
	// some specific structures for reduce method #5
	//struct pixel_reference
	//{
	//	unsigned short pixel_x;
	//	unsigned short pixel_y;
	//	int inref;

	//} __attribute__((packed));
	
//	static const int max_pixel_references = 8192;
	static const int max_neuron_references = 1024;

	class RGB8
	{
	public:

		RGB8()
			: r(0), g(0), b(0), a(0)
		{
		}

		byte_t r;
		byte_t g;
		byte_t b;
		byte_t a;
	};
	
	struct neuron
	{
//		int num_pixel_references;
//		pixel_reference pix_references[max_pixel_references];
		word_t index;
		double wx;
		double wy;
		double wz;
		double vx;
		double vy;
		double vz;
	} __attribute__((packed));
	
	struct neuron_reference
	{
		short ineuron;
		double rho;
	} __attribute__((packed));
	
	struct pixel_record
	{
//		float cx;	// cached colour vector - defined as floats for CIE experiments - 8bit RGB would do otherwise. 
//		float cy;	// will probably change this again after more CIE experiments, or split the impl.
//		float cz;	// note: performing indirect re-lookup/transform each time during solver eliminates these - but is a way too slow for CIE & other spaces
		double ix;
		double iy;
		double iz;
		float weight;
//		unsigned int cycle;
		short num_neuron_references;
		neuron_reference neuron_references[max_neuron_references];
	} __attribute__((packed));

	int target_colours_;
	FIBITMAP *image_;
	RGB8 *palette_rgb_;
	int *histogram_;
	int w_;
	int h_;
	int num_unique_source_cols_;

	unsigned long num_neurons_;
	neuron* neurons_;
	unsigned long num_pixel_records_;
	pixel_record* pixel_records_;
	mersenne_twister exposure_twister_;

	float exp_solutions_[max_neuron_references];
	inline void init_exp_solutions(arg_real _radius);

	bool can_reduce() const { return (num_unique_source_cols_ > target_colours_); }

	void init();

	void generate_colours_pass1_associate();
	void generate_colours_pass2_train();
	void generate_colours_pass3_merge();

	void allocate_pixels_remap_();
	calc_real score();

	inline void present(pixel_record& rrec /*, arg_real alpha, arg_real radius*/);

	inline int match_colour(signed short sr, signed short sg, signed short sb);

public:

	bool analyse();
	void generate_colours();
	void remap_pixels();
	
	Quantize_SOM(FIBITMAP* _image, int _target_colours);
	
	~Quantize_SOM();
	
};

// --------------------------------------------------------------------

#endif // quantize_som_h_
